@@ -1,5 +1,5 @@
 import sys, os
-from sequana_pipelines.demultiplex import check_samplesheet
+from sequana.iem import IEM
 import easydev
 
 sequana_path = easydev.get_package_location('sequana_demultiplex')
@@ -8,32 +8,28 @@ sharedir = os.sep.join([sequana_path , "sequana_pipelines", 'demultiplex', 'data
 
 
 def test_noerror():
-    sys.argv = ["test", "-s", sharedir + "/SampleSheet.csv"];
-    check_samplesheet.main()
+    IEM(sharedir + "/SampleSheet.csv").validate()
 
 
 def test_error1():
-    sys.argv = ["test", "-s", sharedir + "/SampleSheet-error1.csv"];
     try:
-        check_samplesheet.main()
+        IEM(sharedir + "/SampleSheet-error1.csv").validate()
         assert False
     except:
         assert True
 
 
 def test_error2():
-    sys.argv = ["test", "-s", sharedir + "/SampleSheet-error2.csv"];
     try:
-        check_samplesheet.main()
+        IEM(sharedir + "/SampleSheet-error2.csv").validate()
         assert False
     except:
         assert True
 
 
 def test_error2():
-    sys.argv = ["test", "-s", sharedir + "/SampleSheet-error3.csv"];
     try:
-        check_samplesheet.main()
+        IEM(sharedir + "/SampleSheet-error3.csv").validate()
         assert False
     except:
         assert True
